@@ -6,7 +6,7 @@ knitr::opts_chunk$set(
   out.width = "100%"
 )
 
-## ----message = FALSE, eval = TRUE---------------------------------------------
+## ----message = FALSE, eval = TRUE, warning=FALSE------------------------------
 library(aopdata)
 library(sf)
 library(ggplot2)
@@ -15,14 +15,16 @@ library(scales)
 
 ## ----message = FALSE, eval = TRUE---------------------------------------------
 # download aop data
-df <- aopdata::read_access(city='Curitiba',
-                       mode='public_transport',
-                      year=2019,
-                      peak = FALSE,
-                      geometry = TRUE,
-                      showProgress = FALSE)
+df <- aopdata::read_access(
+  city = 'Curitiba',
+  mode = 'public_transport',
+  year = 2019,
+  peak = FALSE,
+  geometry = TRUE,
+  showProgress = FALSE
+  )
 
-## ----message = FALSE, eval = TRUE---------------------------------------------
+## ----message = FALSE, eval = !is.null(df)-------------------------------------
 ggplot() +
   geom_sf(data=df, aes(fill=CMATT60), color=NA, alpha=.9) +
   scale_fill_viridis_c(option = "inferno", labels = scales::comma) +
@@ -30,9 +32,7 @@ ggplot() +
        subtitle='by public transport in less than 60 min.') +
   theme_void()
 
-
-
-## ----message = FALSE, eval = TRUE---------------------------------------------
+## ----message = FALSE, eval = !is.null(df)-------------------------------------
 ggplot() +
   geom_sf(data=df, aes(fill=CMAET30), color=NA, alpha=.9) +
   scale_fill_viridis_c(option = "cividis", labels=scales::comma) +
@@ -40,4 +40,3 @@ ggplot() +
        subtitle='by public transport in less than 30 min.', fill="N. of schools") +
   theme_void()
 
-
